@@ -7,7 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2011, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -356,8 +356,7 @@ module SiSU_EPUB_Tune
           end
           dob.obj.gsub!(/<a href="\.\.\//,%{<a href="#{@vz.url_site}/})
         else
-          dob.obj.gsub!(/(^|[^}])_</m,'\1&lt;'); dob.obj.gsub!(/(^|[^}])_>/m,'\1&gt;') #code-block: angle brackets special characters
-          dob.obj.gsub!(/(^|[^}])_</m,'\1&lt;'); dob.obj.gsub!(/(^|[^}])_>/m,'\1&gt;')
+          dob.obj.gsub!(/</m,'&lt;'); dob.obj.gsub!(/>/m,'&gt;')
         end
         @tuned_file << dob
       end
