@@ -1366,6 +1366,14 @@ WOK
         '^\copyright \textnormal{\1} \2') # watch likely to be problematic
       str
     end
+    def special_characters_safe_close(str)
+      str.gsub!(/<=tilde>/,'{$\tilde$}')
+      str.gsub!(/<=hash>/,'{\#}')
+      str.gsub!(/<=amp>/,'{\\\&}') #changed ... 2005
+      str.gsub!(/<=copymark>\s*(.+)/,
+        '^\copyright \textnormal{\1} \2') # watch likely to be problematic
+      str
+    end
     def special_characters_code_fix(str)
       str.gsub!(/<=tilde>/,'{$\tilde$}')
       str
@@ -1398,6 +1406,7 @@ WOK
       str,is=@txt,@is
       str=xetex_special_characters_1(str,is) unless str.nil?
       str=xetex_special_characters_2(str,is) unless str.nil? # remove this to start with, causes issues
+      str=special_characters_safe_close(str) unless str.nil?
       @txt=str
     end
     def characters_code_listings                                   #special characters - some substitutions are sequence sensitive, rearrange with care.
