@@ -266,7 +266,7 @@ module SiSU_urls
         if x=~/^o/ \
         and @opt.cmd=~/o/ \
         and x=~/^[#{@opt.cmd}]/
-          SiSU_Screen::Ansi.new(@opt.cmd,"-#{x}","#{@prog.text_editor} #{@env.processing_path.odf}/content.xml").maintenance #not implemented
+          SiSU_Screen::Ansi.new(@opt.cmd,"-#{x}","#{@prog.text_editor} #{@env.processing_path.odf}/#{@opt.fns}/odt/content.xml").maintenance
         end
       end
     end
