@@ -119,7 +119,7 @@ module SiSU_DAL
         create_dal
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@@fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get                                                                    #reads dal, unless does not exist then creates first
@@ -135,7 +135,7 @@ module SiSU_DAL
         dal=(@@dal_array.empty?) ? read_fnc : @@dal_array.dup
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_idx_sst                                                            #reads dal idx.sst, #unless does not exist then creates first
@@ -151,7 +151,7 @@ module SiSU_DAL
         dal=(@@idx_arr[:sst].empty?) ? read_idx_sst : @@idx_arr[:sst].dup #check
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_idx_tex                                                            #reads dal idx.tex, #unless does not exist then creates first
@@ -167,7 +167,7 @@ module SiSU_DAL
         dal=(@@idx_arr[:tex].empty?) ? read_idx_tex : @@idx_arr[:tex].dup #check
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_idx_html                                                           #reads dal idx.html, #unless does not exist then creates first
@@ -183,7 +183,7 @@ module SiSU_DAL
         dal=(@@idx_arr[:html].empty?) ? read_idx_html : @@idx_arr[:html].dup
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_idx_xhtml                                                          #reads dal idx.xhtml, #unless does not exist then creates first
@@ -199,7 +199,7 @@ module SiSU_DAL
         dal=(@@idx_arr[:xhtml].empty?) ? read_idx_xhtml : @@idx_arr[:xhtml].dup
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_map_nametags                                                       #reads dal map.nametags, #unless does not exist then creates first
@@ -215,7 +215,7 @@ module SiSU_DAL
         dal=(@@map_arr[:nametags].empty?) ? read_map_nametags : @@map_arr[:nametags].dup
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
     def get_map_ocn_htmlseg                                                    #reads dal map.ocn_htmlseg, #unless does not exist then creates first
@@ -231,7 +231,7 @@ module SiSU_DAL
         dal=(@@map_arr[:ocn_htmlseg].empty?) ? read_map_ocn_htmlseg : @@map_arr[:ocn_htmlseg].dup
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
-        Instantiate.new
+        SiSU_DAL::Instantiate.new
       end
     end
   protected
@@ -475,15 +475,15 @@ module SiSU_DAL
       reset
       data=@data
       data=data.join.split("\n\n")
-      data=SiSU_DAL_Insertions::Insertions.new(@md,data).expand_insertions?                                                # dal_expand_insertions.rb
+      data=SiSU_DAL_Insertions::Insertions.new(@md,data).expand_insertions?                                              # dal_expand_insertions.rb
       data=SiSU_DAL_SubstituteAndInsert::SI.new(@md,data).substitutions_and_insertions?                                  # dal_substitutions_and_insertions.rb
       data,metadata=SiSU_DAL_DocumentStructureExtract::Build.new(@md,data).identify_parts                                # dal_doc_str.rb
-      data=SiSU_DAL_Syntax::Markup.new(@md,data).songsheet                                                                 # dal_syntax.rb
-      data,endnote_array=SiSU_DAL_CharacterCheck::Check.new(data).character_check_and_oldstyle_endnote_array              # dal_character_check.rb
-      data=SiSU_DAL_Images::Images.new(@md,data).images                                                                    # dal_images.rb
-      data,tags_map,ocn_html_seg_map=SiSU_DAL_Numbering::Numbering.new(@md,data).numbering_song                            # dal_numbering.rb
+      data=SiSU_DAL_Syntax::Markup.new(@md,data).songsheet                                                               # dal_syntax.rb
+      data,endnote_array=SiSU_DAL_CharacterCheck::Check.new(data).character_check_and_oldstyle_endnote_array             # dal_character_check.rb
+      data=SiSU_DAL_Images::Images.new(@md,data).images                                                                  # dal_images.rb
+      data,tags_map,ocn_html_seg_map=SiSU_DAL_Numbering::Numbering.new(@md,data).numbering_song                          # dal_numbering.rb
       data,book_index_rel,book_index_rel_html_seg,html_idx,xhtml_idx=SiSU_DAL_BookIndex::BookIndex.new(@md,data,@env).indexing_song if @md.book_idx  # dal_idx.rb
-      data=SiSU_DAL_Endnotes::Endnotes.new(@md,data,endnote_array).endnotes                                                # dal_endnotes.rb
+      data=SiSU_DAL_Endnotes::Endnotes.new(@md,data,endnote_array).endnotes                                              # dal_endnotes.rb
       outputdata=data
       if @md.opt.cmd =~/[mM]/
         SiSU_DAL::Output.new(@fn,@md,outputdata).hard_output
