@@ -66,7 +66,7 @@ module SiSU_DbCreate
       @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
       @comment=(@sql_type=='pg') \
-      ? (Comment.new(@conn,@sql_type))
+      ? (SiSU_DbCreate::Comment.new(@conn,@sql_type))
       : nil
       @@dl ||=SiSU_Env::InfoEnv.new.digest.length
     end
