@@ -106,7 +106,7 @@ module SiSU_EPUB
         data=@tuned_file_array
         scr_toc=SiSU_EPUB::Source::ScrollHeadAndSegToc.new(@md,toc).in_common #watch
         SiSU_EPUB::Source::Seg.new(@md,data).songsheet
-        SiSU_EPUB::Source::EPUB_Output.new(@md).songsheet
+        SiSU_EPUB::Source::Output.new(@md).songsheet
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         unless @opt.cmd =~/[MV]/ #check maintenance flag
@@ -242,7 +242,7 @@ module SiSU_EPUB
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_s_a)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,name_s_a)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,name_s_a)
-              Toc.new(@md,dob_toc).level_1
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_1
             when 2
               @s_b_no +=1
               name_s_b='section_b' + @s_b_no.to_s
@@ -257,7 +257,7 @@ module SiSU_EPUB
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_s_b)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,name_s_b)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,name_s_b)
-              Toc.new(@md,dob_toc).level_2
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_2
             when 3
               @s_c_no +=1
               name_s_c='section_c' + @s_c_no.to_s
@@ -271,7 +271,7 @@ module SiSU_EPUB
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc,name_s_c)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc,name_s_c)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc,name_s_c)
-              Toc.new(@md,dob_toc).level_3
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_3
             when 4
               @ncx_cls=[]
               @nav_no+=1
@@ -281,9 +281,9 @@ module SiSU_EPUB
               md_opf_a_content << @epub.metadata_opf.manifest_content(dob_toc)
               md_opf_a_spine << @epub.metadata_opf.spine(dob_toc)
               md_opf_a_guide << @epub.metadata_opf.guide(dob_toc)
-              Toc.new(@md,dob_toc).level_4
-            when 5; Toc.new(@md,dob_toc).level_5
-            when 6; Toc.new(@md,dob_toc).level_6
+              SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_4
+            when 5; SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_5
+            when 6; SiSU_EPUB::Source::Toc.new(@md,dob_toc).level_6
             else nil
             end
             toc.each do |k,d|
@@ -318,8 +318,8 @@ module SiSU_EPUB
         @@toc[:opf] << @epub.metadata_opf.guide_open << md_opf_a_guide << @epub.metadata_opf.guide_close
         @@toc[:opf] << @epub.metadata_opf.package_close
         @@toc[:opf]=@@toc[:opf].flatten
-        EPUB_Output.new(@md,@@toc[:opf]).epub_metadata_opf
-        EPUB_Output.new(@md,@@toc[:ncx]).epub_toc_ncx
+        SiSU_EPUB::Source::Output.new(@md,@@toc[:opf]).epub_metadata_opf
+        SiSU_EPUB::Source::Output.new(@md,@@toc[:ncx]).epub_toc_ncx
         @md.firstseg=@@firstseg
         @@toc
       end
@@ -486,29 +486,6 @@ module SiSU_EPUB
         end
         toc
       end
-      def level_crosslink
-        dob=@data
-        if dob !~/^4~!/
-          dob.gsub!(/^4~!\s+(\S+)\s+(.+)/,
-            %{<table><tr><td width =\"80\"></td>
-  <td><a href="http://\\1">
-    #{@png.crosslink_ext}
-      &nbsp;&nbsp;\\2
-    <\/a>
-  </td></tr></table>
-})
-        else
-          dob.gsub!(/^4~!\s+(\S+)\s+(.+)/,
-            %{<table><tr><td width ="80">
-  </td><td>
-    <a href="\\1">
-      #{@png.crosslink}
-        &nbsp;&nbsp;\\2
-    <\/a>
-  </td></tr></table>
-})
-        end
-      end
     end
     class ScrollHeadAndSegToc < Toc
       def initialize(md='',toc='',links_guide_toc='')
@@ -521,7 +498,7 @@ module SiSU_EPUB
         SiSU_Screen::Ansi.new(@md.opt.cmd,'Scroll & Segtoc').txt_grey if @md.opt.cmd =~/[MVv]/
         format_head_toc=SiSU_EPUB_Format::HeadToc.new(@md)
         dochead=format_head_toc.head
-        dochead.gsub!(/toc\.(html)/,'doc.\1') #kludge
+        dochead=dochead.gsub(/toc\.(html)/,'doc.\1') #kludge
         toc_shared << dochead #<< ads.div.major
         segtoc << format_head_toc.head #<< ads.div.major
         if SiSU_EPUB_Format::HeadToc.method_defined? :toc_head_escript
@@ -589,8 +566,8 @@ module SiSU_EPUB
         #Segtoc tail added here
         segtoc << seg_toc_band_bottom
         segtoc << format_head_toc.xhtml_close
-        segtoc.flatten!.compact!
-        EPUB_Output.new(@md,segtoc).segtoc
+        segtoc=segtoc.flatten.compact #watch
+        SiSU_EPUB::Source::Output.new(@md,segtoc).segtoc
         segtoc=[]
         @toc[:scr],@toc[:seg]=[],[]
         toc_shared
@@ -600,7 +577,7 @@ module SiSU_EPUB
     end
     class Seg < SiSU_EPUB_Seg::Seg
     end
-    class EPUB_Output
+    class Output
       def initialize(md,output='')
         @md,@output=md,output
         @epub_doc="#{@md.fnb}.epub"
@@ -689,7 +666,7 @@ module SiSU_EPUB
           filename_html_segtoc=@make.epub.xhtml_segtoc
           filename_html_index=@make.epub.xhtml_index
           @output.each do |para|
-            para.strip!
+            para=para.strip
             unless para =~/\A\s*\Z/
               filename_html_segtoc.puts para,"\n"
               filename_html_index.puts para,"\n"
