@@ -144,7 +144,7 @@ module SiSU_Harvest_Topics
           g=@idx_list.scan(/[^;]+/)
           idxl=[]
           g.each do |i|
-            i.strip!
+            i=i.strip
             idxl << { filename: filename, file: file, rough_idx: i, title: @fulltitle, author: creator, page: page, lang: lang  }
           end
           idxl
@@ -153,7 +153,7 @@ module SiSU_Harvest_Topics
       else
         p "missing required field in #{@filename} - [title]: <<#{@title}>>; [author]: <<#{@author_format}>>; [idx]: <<#{@idx_list}>>" if @opt.cmd.inspect =~/[VM]/
       end
-      idx_array[lang].flatten!
+      idx_array[lang]=idx_array[lang].flatten
       idx_array
     end
   end
