@@ -92,13 +92,13 @@ module SiSU_Manifest
           SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}").grey_tab if @opt.cmd =~/v/i
         end
         data=SiSU_HTML::Source::HTML_Environment.new(@particulars).tuned_file_instructions
-        OutputInfo.new(@md).check_output(data)
+        SiSU_Manifest::Source::Output.new(@md).check_output(data)
       rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
     private
-    class OutputInfo <Source
+    class Output <Source
       def initialize(md)
         @manifest={ txt: [], html: [] }
         @md,@fns=md,md.fns
@@ -117,8 +117,8 @@ module SiSU_Manifest
       def output
         manifest=@f.write_file.manifest
         @manifest[:html].each do |x|
-          x.gsub!(Xx[:html_relative2],@f.path_rel_links.html_scroll_2)
-          x.gsub!(Xx[:html_relative1],@f.path_rel_links.html_scroll_1)
+          x=x.gsub(Xx[:html_relative2],@f.path_rel_links.html_scroll_2).
+            gsub(Xx[:html_relative1],@f.path_rel_links.html_scroll_1)
           manifest << x
         end
       end
@@ -180,8 +180,7 @@ module SiSU_Manifest
           end
         end
         manifests
-        @m.uniq!
-        @m
+        @m=@m.uniq
       end
       def languages(id,file)
         flv=published_manifests?
@@ -201,7 +200,7 @@ module SiSU_Manifest
         end
       end
       def metadata(id,info)
-        info.to_s.gsub!(/#{Mx[:br_line]}/,'<br />')
+        info=info.to_s.gsub(/#{Mx[:br_line]}/,'<br />')
         @manifest[:html] << %{<tr><th class="left"><p class="bold_left">#{id}:</p></th><td><p class="left">#{info}</p></td></tr>\n}
       end
       def links(url,lnk,target)
@@ -772,8 +771,8 @@ WOK
           if @env.manifest_minitoc?
             if @env.output_dir_structure.by_language_code? \
             or @env.output_dir_structure.by_filetype?
-              minitoc.gsub!(/<a href="(\S+?)"/m,%{<a href="../html/#{@md.fnb}/\\1"})
-              minitoc.gsub!(/<a href="\.\.\/html\/#{@md.fnb}\/(?:sisu_manifest\.html|#{@f.base_filename.manifest})"/m,
+              minitoc=minitoc.gsub(/<a href="(\S+?)"/m,%{<a href="../html/#{@md.fnb}/\\1"}).
+                gsub(/<a href="\.\.\/html\/#{@md.fnb}\/(?:sisu_manifest\.html|#{@f.base_filename.manifest})"/m,
               %{<a href="#{@f.base_filename.manifest}"})
             end
             @manifest[:html] <<<<WOK
