@@ -138,17 +138,17 @@ module SiSU_Manpage
           else                              SiSU_TextUtils::Wrap.new(e.to_s,78,0,1)
           end
           wrap=util.line_wrap
-          if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
-            wrap.gsub!(/\s\.(\S+)/,' \\.\1')
-            wrap.gsub!(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
+          wrap=if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
+            wrap.gsub(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*'). #man page requires
+              gsub(/\s\.(\S+)/,' \\.\1').
+              gsub(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 .TP
 .BI \\1.
 \\2
 GSUB
                       )
           else
-            wrap.gsub!(/^\s*(.+)\Z/m, <<GSUB
+            wrap.gsub(/^\s*(.+)\Z/m, <<GSUB
 \\1
 GSUB
                       )
@@ -220,7 +220,7 @@ WOK
           else util=SiSU_TextUtils::Wrap.new(paragraph,78,0)
           end
           w=util.line_wrap
-          w.gsub!(/^(\\\.)/,' \1')
+          w=w.gsub(/^(\\\.)/,' \1')
           w
         end
         if lv
@@ -234,7 +234,7 @@ WOK
           end
         else
           @manpage[:body] << if  wrapped =~/^\.BI\s/ # main text, contents, body KEEP
-            '.TP' << @br << wrapped.gsub!(/^\.BI\s/,'.B ') # sleight ... simpler output
+            '.TP' << @br << wrapped.gsub(/^\.BI\s/,'.B ') # sleight ... simpler output (check gsub!)
           else
             '.br' << @br << wrapped
           end
@@ -263,76 +263,76 @@ WOK
           or dob.is=='heading_insert'
             dob.obj=''
           end
-          dob.obj.gsub!(/.+?<-#>/,'')                                           # remove dummy headings (used by html) #check
-          dob.obj.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'^\1^')
-          dob.obj.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'[\1]')
-          dob.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'++\1++')
-          dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'--\1--')
-          dob.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'"\1"')
-          dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1')
-          dob.obj.gsub!(/\A\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}#{Mx[:br_line]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\A\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?#{Mx[:br_line]}/m,"#{Mx[:br_line]}.BI \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.B \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
+          dob.obj=dob.obj.gsub(/.+?<-#>/,'').                                           # remove dummy headings (used by html) #check
+            gsub(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'^\1^').
+            gsub(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'[\1]').
+            gsub(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'++\1++').
+            gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'--\1--').
+            gsub(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'"\1"').
+            gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1').
+            gsub(/\A\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}#{Mx[:br_line]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}").
+            gsub(/\A\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?#{Mx[:br_line]}/m,"#{Mx[:br_line]}.BI \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.B \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
           unless dob.is=='code'
-            dob.obj.gsub!(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1 #{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
-            dob.obj.gsub!(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1#{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
+            dob.obj=dob.obj.gsub(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1 #{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3").
+              gsub(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1#{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
             @manpage[:endnotes]=extract_endnotes(dob.obj)
-            dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_b_c]}/m,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:gl_o]}#amp#{Mx[:gl_c]}/,'&') ##{Mx[:gl_o]}#095#{Mx[:gl_c]}
-            dob.obj.gsub!(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\e')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
+            dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:en_b_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_b_c]}/m,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:gl_o]}#amp#{Mx[:gl_c]}/,'&'). ##{Mx[:gl_o]}#095#{Mx[:gl_c]}
+              gsub(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!').
+              gsub(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#').
+              gsub(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*').
+              gsub(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-').
+              gsub(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\e').
+              gsub(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/').
+              gsub(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_').
+              gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+              gsub(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}').
+              gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+              gsub(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
           else
-            dob.obj.gsub!(/\\/,'\e')
-            dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
+            dob.obj=dob.obj.gsub(/\\/,'\e').
+              gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
             #dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/,"\n")                                   # watch
           end
-          dob.obj.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
-          dob.obj.gsub!(/┆/,'|')
-          dob.obj.gsub!(/\s\.(\S+)/,' \\.\1')
-          dob.obj.gsub!(/(\n\.)(\S\S\S+)/m,'\1\\.\2')
-          dob.obj.gsub!(/-/,'\-') #manpages use this
-          dob.obj.gsub!(/&#126;/,'~') if dob.obj #manpages use this
+          dob.obj=dob.obj.gsub(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*'). #man page requires
+            gsub(/┆/,'|').
+            gsub(/\s\.(\S+)/,' \\.\1').
+            gsub(/(\n\.)(\S\S\S+)/m,'\1\\.\2').
+            gsub(/-/,'\-') #manpages use this
+          dob.obj=dob.obj.gsub(/&#126;/,'~') if dob.obj #manpages use this
           if dob.is =~/block|group|verse|alt|code/
             if dob.is =='code'
-              dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
-              dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
-              dob.obj.gsub!(/\A(.+)?\Z/m,".nf\n\n\\1\n\n.fi")
+              dob.obj=dob.obj.gsub(/(^|[^}])_([<>])/m,'\1\2'). # _> _<
+                gsub(/(^|[^}])_([<>])/m,'\1\2'). # _<_<
+                gsub(/\A(.+)?\Z/m,".nf\n\n\\1\n\n.fi")
             end
           end
           #dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n.br\n")                                   # watch
-          dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n\n")                                   # watch
+          dob.obj=dob.obj.gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n\n")                                   # watch
           blit=dob.obj.scan(/\[[^\]]+\]|[^\[]+/)
           blit_array=[]
           blit.each do |x|
-            if x =~/^\[/
-              x.gsub!(/\s+/,' \ ') #manpages use this
+            x=if x =~/^\[/
+              x.gsub(/\s+/,' \ ') #manpages use this
             else x
             end
             blit_array << x
           end
           dob.obj=blit_array.join
-          dob.obj.gsub!(/#{Mx[:gl_o]}:name#\S+?#{Mx[:gl_c]}/mi,'') #added
-          #dob.obj.gsub!(/\s\\\s+(#{Mx[:br_line]}|#{Mx[:br_nl]})/,'\1') #a messy solution
-          dob.obj.gsub!(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'')                                         # remove page breaks
-          dob.obj.gsub!(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1\2')
-          dob.obj.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
-          dob.obj.gsub!(/#{Mx[:mk_o]}name#\S+?#{Mx[:mk_c]}/,'')                                     # remove name links
-          dob.obj.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')                                          # decide on
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/^(?:^|[^_\\])#{Mx[:lnk_o]}\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*#{Mx[:lnk_c]}\S+/,'[image: "\1"]')
+          dob.obj=dob.obj.gsub(/#{Mx[:gl_o]}:name#\S+?#{Mx[:gl_c]}/mi,''). #added
+          #gsub(/\s\\\s+(#{Mx[:br_line]}|#{Mx[:br_nl]})/,'\1'). #a messy solution
+            gsub(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'').                                         # remove page breaks
+            gsub(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1\2').
+            gsub(/<a href=".+?">(.+?)<\/a>/m,'\1').
+            gsub(/#{Mx[:mk_o]}name#\S+?#{Mx[:mk_c]}/,'').                                     # remove name links
+            gsub(/&nbsp;|#{Mx[:nbsp]}/,' ').                                          # decide on
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/^(?:^|[^_\\])#{Mx[:lnk_o]}\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*#{Mx[:lnk_c]}\S+/,'[image: "\1"]')
           wordlist=dob.obj.scan(/\S+/)
           if dob.obj !~/(^#{Rx[:meta]}|#{Mx[:br_eof]}|#{Mx[:br_endnotes]})/
             if dob.obj =~@regx #/.+?<~\d+;\w\d+;\w\d+>.*/ #watch change
@@ -362,14 +362,14 @@ WOK
               dob.obj=''
             end
             if dob.obj
-              dob.obj.gsub!(/\s(\[)/m,' \ \1')
-              dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
-              dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-              dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-              dob.obj.gsub!(/#{Mx[:pa_o]}\S+#{Mx[:pa_c]}/,' ')
+              dob.obj=dob.obj.gsub(/\s(\[)/m,' \ \1').
+                gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n").                                   # watch
+                gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+                gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+                gsub(/#{Mx[:pa_o]}\S+#{Mx[:pa_c]}/,' ')
               unless dob.is =='code'
-                dob.obj.gsub!(/<!.+!>/,' ')
-                dob.obj.gsub!(/<:\S+>/,' ')
+                dob.obj=dob.obj.gsub(/<!.+!>/,' ').
+                  gsub(/<:\S+>/,' ')
               end
             end
             dob
@@ -416,7 +416,7 @@ WOK
           if para.class==Array \
           and para.length > 0
             para.each do |line|
-              line.gsub!(/\s+$/m,'')
+              line=line.gsub(/\s+$/m,'')
               filename_manpage.puts line           #unix manpage
             end
           else filename_manpage.puts para          #unix manpage # /^([*=-]|\.){5}/
