@@ -87,7 +87,8 @@ module SiSU_Commandline
             x << Dir.glob("#{d}/*.ss[tm]")
           end
         end
-        opt + x.flatten!
+        x=x.flatten
+        opt + x
       end
     end
     def find_select(find_flag,opt)
@@ -112,8 +113,8 @@ module SiSU_Commandline
             end
           end
         end
-        x.flatten!
-     end
+        x.flatten
+      end
     end
     def sisu_glob_rules(a)
       a=if a.inspect =~/"-[A-Za-z0-9]*[fG]/ \
@@ -140,7 +141,7 @@ module SiSU_Commandline
           end
         end
         r=Px[:lng_lst].join('|')
-        r.gsub!(/\|#{@lng_base}\|/,'|')
+        r=r.gsub(/\|#{@lng_base}\|/,'|')
         @lang_regx=%r{(?:#{r})}
         z=if find_flag
           (f.length > 0) \
@@ -188,7 +189,7 @@ module SiSU_Commandline
         end
         SiSU_Screen::Ansi.new(@cmd,"\tsisu " + @cmd +  ' ' + @mod.join(' ') + ' ' + @files.join(' ') + "\n").print_brown if @cmd =~/[vVM]/
       end
-#     @files.uniq!
+#     @files=@files.uniq
       @act=opt_act
       @files
       self
@@ -229,7 +230,7 @@ module SiSU_Commandline
             fn = (y[r_f,1]) \
               ? y[r_f,1]
               : y
-            fn.gsub!(/\.((?:ssm\.)?sst)/,'.-\1')
+            fn=fn.gsub(/\.((?:ssm\.)?sst)/,'.-\1')
             fullname=Dir.pwd + '/' + fn
             pt=Pathname.new(fullname)
             pth << Dir.pwd
@@ -388,7 +389,7 @@ module SiSU_Commandline
       end
       ca=[]
       unless c.empty?
-        c.gsub!(/-/,'')
+        c=c.gsub(/-/,'')
         c.scan(/CC|\S/) {|x| ca << x}
         cmd= '-' + ca.uniq.join
       end
