@@ -74,7 +74,7 @@ module SiSU_Po4a
       #  puts "#{@opt.fns} not a processed file type"
       #end
       r=Px[:lng_lst].join('|')
-      r.gsub!(/\|en\|/,'|')
+      r=r.gsub(/\|en\|/,'|')
       @lang_regx=%r{(?:#{r})}
       if opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
       and opt.f_pth[:lng]!=opt.lng_base
@@ -187,9 +187,9 @@ module SiSU_Po4a
         @n=[]
         notes_a.flatten.each do |n| #high cost to deal with <br> appropriately within plaintext, consider
           n=n.dup.to_s
-          n.gsub!(/^([\d]+)\s+/,'^~\1 ')
-          #n.gsub!(/^([\d*+]+)\s+/,'^~\1 ')
-          n.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,'<br>')
+          n=n.gsub(/^([\d]+)\s+/,'^~\1 ').
+           #gsub(/^([\d*+]+)\s+/,'^~\1 ').
+            gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,'<br>')
           @n << n
         end
         notes_a=@n.flatten
@@ -219,13 +219,13 @@ module SiSU_Po4a
           end
           util=pot_structure(desc,orig,trans)
           wrap=util.line_wrap
-          if wrap =~ /^\s*\^~[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub!(/^\s*(\^~[\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
+          wrap=if wrap =~ /^\s*\^~[\d*+]+\s+.+?\s*\Z/m
+            wrap.gsub(/^\s*(\^~[\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 \\1 \\2
 GSUB
                       )
           else
-            wrap.gsub!(/^(.+)\Z/m, <<GSUB
+            wrap.gsub(/^(.+)\Z/m, <<GSUB
 \\1
 GSUB
                       )
@@ -681,9 +681,9 @@ GSUB
         end
         desc="#{d}#{s_mark}#{instruct}"
         orig=dob_src.obj
-        orig.gsub!(/#{Mx[:tc_c]}/,"\n")
+        orig=orig.gsub(/#{Mx[:tc_c]}/,"\n")
         trans=(dob_trn=='') ? '' : dob_trn.obj
-        trans.gsub!(/#{Mx[:tc_c]}/,"\n")
+        trans=trans.gsub(/#{Mx[:tc_c]}/,"\n")
         util=pot_structure(desc,orig,trans)
         unwrapped=util.no_line_wrap_block
         @pot[:body] << unwrapped << @br
@@ -829,79 +829,81 @@ GSUB
           end
           dob_src='' if (dob_src.obj =~/<a name="n\d+">/ \
           and dob_src.obj =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
-          dob_src.obj.gsub!(/<!.+!>/,' ') if dob_src ## Clean Prepared Text
-          dob_src.obj.gsub!(/<:\S+>/,' ') if dob_src ## Clean Prepared Text
+          if dob_src ## Clean Prepared Text
+            dob_src.obj=dob_src.obj.gsub(/<!.+!>/,' ').
+              gsub(/<:\S+>/,' ') if dob_src ## Clean Prepared Text
+          end
         end
         #[dob_src,dob_trn]
       end
       def markup(dob)                                     # Used for major markup instructions
         dir=SiSU_Env::InfoEnv.new(@md.fns)
         fix=[]
-          dob.obj.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,
-            "#{Px[:po_bold_o]}\\1#{Px[:po_bold_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,
-            "#{Px[:po_italics_o]}\\1#{Px[:po_italics_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,
-            "#{Px[:po_underscore_o]}\\1#{Px[:po_underscore_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,
-            "#{Px[:po_subscript_o]}\\1#{Px[:po_subscript_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,
-            "#{Px[:po_superscript_o]}\\1#{Px[:po_superscript_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,
-            "#{Px[:po_insert_o]}\\1#{Px[:po_insert_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,
-            "#{Px[:po_cite_o]}\\1#{Px[:po_cite_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,
-            "#{Px[:po_strike_o]}\\1#{Px[:po_strike_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,
-            "#{Px[:po_monospace_o]}\\1#{Px[:po_monospace_c]}")
+          dob.obj=dob.obj.gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,
+              "#{Px[:po_bold_o]}\\1#{Px[:po_bold_c]}").
+            gsub(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,
+              "#{Px[:po_italics_o]}\\1#{Px[:po_italics_c]}").
+            gsub(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,
+              "#{Px[:po_underscore_o]}\\1#{Px[:po_underscore_c]}").
+            gsub(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,
+              "#{Px[:po_subscript_o]}\\1#{Px[:po_subscript_c]}").
+            gsub(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,
+              "#{Px[:po_superscript_o]}\\1#{Px[:po_superscript_c]}").
+            gsub(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,
+              "#{Px[:po_insert_o]}\\1#{Px[:po_insert_c]}").
+            gsub(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,
+              "#{Px[:po_cite_o]}\\1#{Px[:po_cite_c]}").
+            gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,
+              "#{Px[:po_strike_o]}\\1#{Px[:po_strike_c]}").
+            gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,
+              "#{Px[:po_monospace_o]}\\1#{Px[:po_monospace_c]}")
           notes=''
           unless dob.is=='code'
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/,'\1')
-            dob.obj.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1')
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]')
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]')
-            dob.obj.gsub!(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1')
+            dob.obj=dob.obj.gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/,'\1').
+              gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1').
+              gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]').
+              gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]').
+              gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1')
             #dob.obj.gsub!(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
             notes=extract_endnotes(dob)
             #% ### footnotes current state - extracted
-            dob.obj.gsub!(/#{Mx[:en_a_o]}([\d]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'~^')   # endnote marker marked up
+            dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'~^').   # endnote marker marked up
             #% ### footnotes current state - keep inline
             #dob.obj.gsub!(/#{Mx[:en_a_o]}[\d]+\s+(.+?)#{Mx[:en_a_c]}/,'~{ \1 }~')     # inline endnote with marker marked up
-            dob.obj.gsub!(/#{Mx[:en_b_o]}[\d]+\s+(.+?)#{Mx[:en_b_c]}/,'~[ \1 ]~')     # inline endnote with marker marked up
-            dob.obj.gsub!(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,'~{\1 \2 }~') # inline endnote with marker marked up
-            dob.obj.gsub!(/#{Mx[:en_b_o]}([*+]+)\s+(.+?)#{Mx[:en_b_c]}/,'~[\1 \2 ]~') # inline endnote with marker marked up
-            dob.obj.gsub!(/#{Mx[:gl_o]}(?:#lt|#060)#{Mx[:gl_c]}/,'<')
-            dob.obj.gsub!(/#{Mx[:gl_o]}(?:#gt|#062)#{Mx[:gl_c]}/,'>')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#(?:038|amp)#{Mx[:gl_c]}/,'&')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
+              gsub(/#{Mx[:en_b_o]}[\d]+\s+(.+?)#{Mx[:en_b_c]}/,'~[ \1 ]~').     # inline endnote with marker marked up
+              gsub(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,'~{\1 \2 }~'). # inline endnote with marker marked up
+              gsub(/#{Mx[:en_b_o]}([*+]+)\s+(.+?)#{Mx[:en_b_c]}/,'~[\1 \2 ]~'). # inline endnote with marker marked up
+              gsub(/#{Mx[:gl_o]}(?:#lt|#060)#{Mx[:gl_c]}/,'<').
+              gsub(/#{Mx[:gl_o]}(?:#gt|#062)#{Mx[:gl_c]}/,'>').
+              gsub(/#{Mx[:gl_o]}#(?:038|amp)#{Mx[:gl_c]}/,'&').
+              gsub(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!').
+              gsub(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#').
+              gsub(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*').
+              gsub(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-').
+              gsub(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/').
+              gsub(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_').
+              gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+              gsub(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}').
+              gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+              gsub(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
           end
-          if dob.of=='block'                                   # watch
-            dob.obj.gsub!(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ")
-            dob.obj.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n")
-          else dob.obj.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n\n")
+          dob.obj=if dob.of=='block'                                   # watch
+            dob.obj.gsub(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ").
+              gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n")
+          else dob.obj.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n\n")
           end
           if dob.is=='code'
-            dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
-            dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
+            dob.obj=dob.obj.gsub(/(^|[^}])_([<>])/m,'\1\2'). # _> _<
+              gsub(/(^|[^}])_([<>])/m,'\1\2') # _<_<
           end
-          dob.obj.gsub!(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'')                     # remove page breaks
-          dob.obj.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1')
-          dob.obj.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
-          dob.obj.gsub!(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'')                       # remove name links
-          dob.obj.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')                                       # decide on
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/(?:^|[^_\\])\{\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
+          dob.obj=dob.obj.gsub(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'').                     # remove page breaks
+            gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1').
+            gsub(/<a href=".+?">(.+?)<\/a>/m,'\1').
+            gsub(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'').                       # remove name links
+            gsub(/&nbsp;|#{Mx[:nbsp]}/,' ').                                       # decide on
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/(?:^|[^_\\])\{\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
         [dob,notes]
       end
       def publish(fn,pot)
@@ -934,8 +936,8 @@ GSUB
           and para.length > 0
             para.each do |line|
               if line
-                line.gsub!(/\s+$/m,'')
-                line.gsub!(/^\A[ ]*\Z/m,'')
+                line=line.gsub(/\s+$/m,'').
+                  gsub(/^\A[ ]*\Z/m,'')
                 if line=~/^\A[ ]*\Z/m
                   emptyline+=1
                 else emptyline=0
