@@ -215,7 +215,7 @@ WOK
         #  "#{url}/sisu_manifest.#{lc}.html"
         #end
         manifests
-        @m.uniq!
+        @m=@m.uniq
         @m
       end
       def languages(id,file)
@@ -232,11 +232,11 @@ WOK
         end
       end
       def metadata(id,info)
-        info.to_s.gsub!(/#{Mx[:br_line]}/,"\n")
+        info=info.to_s.gsub(/#{Mx[:br_line]}/,"\n")
         @manifest[:txt] << %{#{id}: #{info}\n}
       end
       def md_title_info(id,info)
-        info.to_s.gsub!(/#{Mx[:br_line]}/,"\n")
+        info=info.to_s.gsub(/#{Mx[:br_line]}/,"\n")
         @manifest[:txt_title] << %{#{info}\n}
       end
       def links(url,lnk,target)
