@@ -135,12 +135,12 @@ module SiSU_XHTML
       end
     protected
       def embedded_endnotes(dob='')
-        dob.obj.gsub!(/#{Mx[:en_a_o]}(\d+)\s+(.+?)#{Mx[:en_a_c]}/,
-          '<endnote><number>\1</number><note>\2</note></endnote> ')
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([*+]\d+)\s+(.+?)#{Mx[:en_b_c]}/,
-          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,
-          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
+        dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}(\d+)\s+(.+?)#{Mx[:en_a_c]}/,
+            '<endnote><number>\1</number><note>\2</note></endnote> ').
+          gsub(/#{Mx[:en_b_o]}([*+]\d+)\s+(.+?)#{Mx[:en_b_c]}/,
+            '<endnote><symbol>\1</symbol><note>\2</note></endnote> ').
+          gsub(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,
+            '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
       end
       def extract_endnotes(dob='')
         notes=dob.obj.scan(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+\s+.+?)(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/)
@@ -148,26 +148,26 @@ module SiSU_XHTML
           s=e.to_s
           util=SiSU_TextUtils::Wrap.new(s,70)
           wrap=util.line_wrap
-          wrap.gsub!(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
+          wrap=wrap.gsub(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote notenumber="\\1">
 #{Ax[:tab]*2}\\1. \\2
 #{Ax[:tab]*1}</endnote>
 WOK
-)
-          wrap.gsub!(/^([*+]\d+)\s+(.+?)\s*\Z/m, <<WOK
+).
+            gsub(/^([*+]\d+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote symbol="\\1">
 #{Ax[:tab]*2}\\1 \\2
 #{Ax[:tab]*1}</endnote>
 WOK
-)
-          wrap.gsub!(/^([*+]+)\s+(.+?)\s*\Z/m, <<WOK
+).
+            gsub(/^([*+]+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote symbol="\\1.length">
 #{Ax[:tab]*2}\\1 \\2
 #{Ax[:tab]*1}</endnote>
 WOK
 )
 #KEEP alternative presentation of endnotes
-#        wrap.gsub!(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
+#        wrap=wrap.gsub(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
 ##{Ax[:tab]*1}<p class="endnote" notenumber="\\1">
 ##{Ax[:tab]*2}\\1. \\2
 ##{Ax[:tab]*1}</p>
@@ -200,8 +200,8 @@ WOK
           else lv=nil
           end
           extract_endnotes(dob)
-          dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-          dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+          dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+            gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
           util=SiSU_TextUtils::Wrap.new(dob.obj,70)
           wrapped=util.line_wrap
           @@xml[:body] << if defined? dob.ocn
@@ -219,9 +219,9 @@ WOK
       def block_structure(dob)
         named=name_tags(dob)
         dob=@trans.markup_block(dob)
-        dob.obj.strip!
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+        dob.obj=dob.obj.strip.
+          gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+          gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="block">#{named}#{Ax[:tab]*1}}
@@ -232,9 +232,9 @@ WOK
       def group_structure(dob)
         named=name_tags(dob)
         dob=@trans.markup_group(dob)
-        dob.obj.strip!
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+        dob.obj=dob.obj.strip.
+          gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+          gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="group">#{named}#{Ax[:tab]*1}}
@@ -245,7 +245,7 @@ WOK
       def poem_structure(dob)
         named=name_tags(dob)
         dob=@trans.markup_group(dob)
-        dob.obj.strip!
+        dob.obj=dob.obj.strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="verse">#{named}#{Ax[:tab]*1}}
@@ -256,8 +256,7 @@ WOK
       def code_structure(dob)
         named=name_tags(dob)
         dob=@trans.markup_group(dob)
-        dob.obj.gsub!(/\s\s/,'&#160;&#160;')
-        dob.obj.strip!
+        dob.obj=dob.obj.gsub(/\s\s/,'&#160;&#160;').strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="code">#{named}#{Ax[:tab]*1}}
@@ -342,7 +341,7 @@ WOK
               end
             else #
             end
-            dob.obj.gsub!(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
+            dob.obj=dob.obj.gsub(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
           end
         end
         6.downto(4) do |x|
@@ -379,7 +378,7 @@ WOK
         content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
         content << @@xml[:tail] << @@xml[:close]
-        content.flatten!.compact!
+        content=content.flatten.compact
         Output.new(content,@md).xhtml
         @@xml={}
       end
@@ -393,7 +392,7 @@ WOK
         SiSU_Env::FileOp.new(@md).mkdir
         filename_xml=@file.write_file.xhtml
         @data.each do |str|
-          str.gsub!(/\A\s+\Z/m,'') #str.gsub!(/^\s+$/,'')
+          str=str.gsub(/\A\s+\Z/m,'') #str.gsub(/^\s+$/,'')
           filename_xml.puts str unless str.empty?
         end
         filename_xml.close
