@@ -134,12 +134,12 @@ module SiSU_XML_SAX
       end
     protected
       def embedded_endnotes(dob='')
-        dob.obj.gsub!(/#{Mx[:en_a_o]}(\d+)\s+(.+?)#{Mx[:en_a_c]}/,
-          '<endnote><number>\1</number><note>\2</note></endnote> ')
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([*+]\d+)\s+(.+?)#{Mx[:en_b_c]}/,
-          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,
-          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
+        dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}(\d+)\s+(.+?)#{Mx[:en_a_c]}/,
+            '<endnote><number>\1</number><note>\2</note></endnote> ').
+          gsub(/#{Mx[:en_b_o]}([*+]\d+)\s+(.+?)#{Mx[:en_b_c]}/,
+            '<endnote><symbol>\1</symbol><note>\2</note></endnote> ').
+          gsub(/#{Mx[:en_a_o]}([*+]+)\s+(.+?)#{Mx[:en_a_c]}/,
+            '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
       end
       def extract_endnotes(dob='')
         notes=dob.obj.scan(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+\s+.+?)(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/)
@@ -147,7 +147,7 @@ module SiSU_XML_SAX
           s=e.to_s
           util=SiSU_TextUtils::Wrap.new(s,70)
           wrap=util.line_wrap
-          wrap.gsub!(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
+          wrap=wrap.gsub(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote notenumber="\\1">
 #{Ax[:tab]*2}<number>\\1</number>
 #{Ax[:tab]*2}<note>
@@ -155,8 +155,8 @@ module SiSU_XML_SAX
 #{Ax[:tab]*2}</note>
 #{Ax[:tab]*1}</endnote>
 WOK
-)
-          wrap.gsub!(/^([*+]\d+)\s+(.+?)\s*\Z/m, <<WOK
+).
+            gsub(/^([*+]\d+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote symbol="\\1">
 #{Ax[:tab]*2}<symbol>\\1</symbol>
 #{Ax[:tab]*2}<note>
@@ -164,8 +164,8 @@ WOK
 #{Ax[:tab]*2}</note>
 #{Ax[:tab]*1}</endnote>
 WOK
-)
-          wrap.gsub!(/^([*+]+)\s+(.+?)\s*\Z/m, <<WOK
+).
+            gsub(/^([*+]+)\s+(.+?)\s*\Z/m, <<WOK
 #{Ax[:tab]*1}<endnote symbol="\\1.length">
 #{Ax[:tab]*2}<symbol>\\1</symbol>
 #{Ax[:tab]*2}<note>
@@ -211,8 +211,8 @@ WOK
         else lv=nil
         end
         extract_endnotes(dob)
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+        dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+          gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
         #if defined? dob.obj
         #t_ograph="#{dob.obj}"
         util=SiSU_TextUtils::Wrap.new(dob.obj,70)
@@ -232,10 +232,10 @@ WOK
       end
       def block_structure(dob='')
         extract_endnotes(dob)
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+        dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+          gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
         dob=@trans.markup_block(dob)
-        dob.obj.strip!
+        dob.obj=dob.obj.strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="block">#{Ax[:tab]*1}}
@@ -247,10 +247,10 @@ WOK
       end
       def group_structure(dob='')
         extract_endnotes(dob)
-        dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>') #footnote/endnote clean
-        dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
+        dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'<en>\1</en>'). #footnote/endnote clean
+          gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'<en>\1</en>') #footnote/endnote clean
         dob=@trans.markup_group(dob)
-        dob.obj.strip!
+        dob.obj=dob.obj.strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="group">#{Ax[:tab]*1}}
@@ -262,8 +262,8 @@ WOK
       end
       def poem_structure(dob='')
         dob=@trans.markup_group(dob)
-        #dob.obj.gsub!(/\s\s/,'&#160;&#160;')
-        dob.obj.strip!
+        #dob.obj.gsub(/\s\s/,'&#160;&#160;')
+        dob.obj=dob.obj.strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="verse">#{Ax[:tab]*1}}
@@ -273,8 +273,7 @@ WOK
       end
       def code_structure(dob='')
         dob=@trans.markup_group(dob)
-        dob.obj.gsub!(/\s\s/,'&#160;&#160;')
-        dob.obj.strip!
+        dob.obj=dob.obj.gsub(/\s\s/,'&#160;&#160;').strip
         @@xml[:body] << %{#{Ax[:tab]*0}<object id="#{dob.ocn}">}
         @@xml[:body] << %{#{Ax[:tab]*1}<ocn>#{dob.ocn}</ocn>}
         @@xml[:body] << %{#{Ax[:tab]*1}<text class="code">#{Ax[:tab]*1}}
@@ -380,7 +379,7 @@ WOK
               end
             else #
             end
-            dob.obj.gsub!(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
+            dob.obj=dob.obj.gsub(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if dob.obj
           end
         end
         6.downto(4) do |x|
@@ -421,7 +420,7 @@ WOK
         content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
         content << @@xml[:tail] << @@xml[:close]
-        content.flatten!.compact!
+        content=content.flatten.compact
         Output.new(content,@md).xml
         @@xml={}
       end
@@ -435,7 +434,7 @@ WOK
         SiSU_Env::FileOp.new(@md).mkdir
         filename_xml=@file.write_file.xml_sax
         @data.each do |str|
-          str.gsub!(/\A\s+\Z/m,'') #str.gsub!(/^\s+$/,'')
+          str=str.gsub(/\A\s+\Z/m,'')
           filename_xml.puts str unless str.empty?
         end
         filename_xml.close
